"""
Python module generated from Java source file org.bukkit.material.Command

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Command(MaterialData, Redstone):
    """
    Represents a command block

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        ...


    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def isPowered(self) -> bool:
        """
        Gets the current state of this Material, indicating if it's powered or
        unpowered

        Returns
        - True if powered, otherwise False
        """
        ...


    def setPowered(self, bool: bool) -> None:
        """
        Sets the current state of this Material

        Arguments
        - bool: whether or not the command block is powered
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "Command":
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerHideEntityEvent

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerHideEntityEvent(PlayerEvent):
    """
    Called when a visible entity is hidden from a player.
    
    This event is only called when the entity's visibility status is actually
    changed.
    
    This event is called regardless of if the entity was within tracking range.

    See
    - Player.hideEntity(org.bukkit.plugin.Plugin, org.bukkit.entity.Entity)

    Unknown Tags
    - draft API
    """

    def __init__(self, who: "Player", entity: "Entity"):
        ...


    def getEntity(self) -> "Entity":
        """
        Gets the entity which has been hidden from the player.

        Returns
        - the hidden entity
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerShearEntityEvent

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.entity import Entity
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import EquipmentSlot
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PlayerShearEntityEvent(PlayerEvent, Cancellable):
    """
    Called when a player shears an entity
    """

    def __init__(self, who: "Player", what: "Entity", item: "ItemStack", hand: "EquipmentSlot"):
        ...


    def __init__(self, who: "Player", what: "Entity"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getEntity(self) -> "Entity":
        """
        Gets the entity the player is shearing

        Returns
        - the entity the player is shearing
        """
        ...


    def getItem(self) -> "ItemStack":
        """
        Gets the item used to shear the entity.

        Returns
        - the shears
        """
        ...


    def getHand(self) -> "EquipmentSlot":
        """
        Gets the hand used to shear the entity.

        Returns
        - the hand
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .PersistentDataType import PersistentDataType
from .PersistentDataHolder import PersistentDataHolder
from .PersistentDataAdapterContext import PersistentDataAdapterContext
from .PersistentDataContainer import PersistentDataContainer


"""
Python module generated from Java source file org.bukkit.block.banner.PatternType

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.banner import *
from typing import Any, Callable, Iterable, Tuple


class PatternType(Enum):

    BASE = ("b")
    SQUARE_BOTTOM_LEFT = ("bl")
    SQUARE_BOTTOM_RIGHT = ("br")
    SQUARE_TOP_LEFT = ("tl")
    SQUARE_TOP_RIGHT = ("tr")
    STRIPE_BOTTOM = ("bs")
    STRIPE_TOP = ("ts")
    STRIPE_LEFT = ("ls")
    STRIPE_RIGHT = ("rs")
    STRIPE_CENTER = ("cs")
    STRIPE_MIDDLE = ("ms")
    STRIPE_DOWNRIGHT = ("drs")
    STRIPE_DOWNLEFT = ("dls")
    STRIPE_SMALL = ("ss")
    CROSS = ("cr")
    STRAIGHT_CROSS = ("sc")
    TRIANGLE_BOTTOM = ("bt")
    TRIANGLE_TOP = ("tt")
    TRIANGLES_BOTTOM = ("bts")
    TRIANGLES_TOP = ("tts")
    DIAGONAL_LEFT = ("ld")
    DIAGONAL_RIGHT = ("rd")
    DIAGONAL_LEFT_MIRROR = ("lud")
    DIAGONAL_RIGHT_MIRROR = ("rud")
    CIRCLE_MIDDLE = ("mc")
    RHOMBUS_MIDDLE = ("mr")
    HALF_VERTICAL = ("vh")
    HALF_HORIZONTAL = ("hh")
    HALF_VERTICAL_MIRROR = ("vhr")
    HALF_HORIZONTAL_MIRROR = ("hhb")
    BORDER = ("bo")
    CURLY_BORDER = ("cbo")
    CREEPER = ("cre")
    GRADIENT = ("gra")
    GRADIENT_UP = ("gru")
    BRICKS = ("bri")
    SKULL = ("sku")
    FLOWER = ("flo")
    MOJANG = ("moj")
    GLOBE = ("glb")
    PIGLIN = ("pig")


    def getIdentifier(self) -> str:
        """
        Returns the identifier used to represent
        this pattern type

        Returns
        - the pattern's identifier
        """
        ...


    @staticmethod
    def getByIdentifier(identifier: str) -> "PatternType":
        """
        Returns the pattern type which matches the passed
        identifier or null if no matches are found

        Arguments
        - identifier: the identifier

        Returns
        - the matched pattern type or null
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.inventory.FurnaceStartSmeltEvent

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import HandlerList
from org.bukkit.event.block import InventoryBlockStartEvent
from org.bukkit.event.inventory import *
from org.bukkit.inventory import CookingRecipe
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class FurnaceStartSmeltEvent(InventoryBlockStartEvent):
    """
    Called when a Furnace starts smelting.
    """

    def __init__(self, furnace: "Block", source: "ItemStack", recipe: "CookingRecipe"[Any]):
        ...


    def getRecipe(self) -> "CookingRecipe"[Any]:
        """
        Gets the FurnaceRecipe associated with this event

        Returns
        - the FurnaceRecipe being cooked
        """
        ...


    def getTotalCookTime(self) -> int:
        """
        Gets the total cook time associated with this event

        Returns
        - the total cook time
        """
        ...


    def setTotalCookTime(self, cookTime: int) -> None:
        """
        Sets the total cook time for this event

        Arguments
        - cookTime: the new total cook time
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerGameModeChangeEvent

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import GameMode
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerGameModeChangeEvent(PlayerEvent, Cancellable):
    """
    Called when the GameMode of the player is changed.
    """

    def __init__(self, player: "Player", newGameMode: "GameMode"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getNewGameMode(self) -> "GameMode":
        """
        Gets the GameMode the player is switched to.

        Returns
        - player's new GameMode
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



from .TranslatableComponent import TranslatableComponent
from .TextComponent import TextComponent
from .SelectorComponent import SelectorComponent
from .ScoreComponent import ScoreComponent
from .Keybinds import Keybinds
from .KeybindComponent import KeybindComponent
from .ItemTag import ItemTag
from .HoverEvent import HoverEvent
from .ComponentBuilder import ComponentBuilder
from .ClickEvent import ClickEvent
from .BaseComponent import BaseComponent


"""
Python module generated from Java source file org.bukkit.entity.MushroomCow

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class MushroomCow(Cow):
    """
    Represents a mushroom Cow
    """

    def getVariant(self) -> "Variant":
        """
        Get the variant of this cow.

        Returns
        - cow variant
        """
        ...


    def setVariant(self, variant: "Variant") -> None:
        """
        Set the variant of this cow.

        Arguments
        - variant: cow variant
        """
        ...


    class Variant(Enum):
        """
        Represents the variant of a cow - ie its color.
        """

        RED = 0
        """
        Red mushroom cow.
        """
        BROWN = 1
        """
        Brown mushroom cow.
        """



"""
Python module generated from Java source file org.bukkit.entity.SplashPotion

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class SplashPotion(ThrownPotion):
    """
    Represents a thrown splash potion bottle

    Deprecated
    - splash status depends on only on the potion item.
    """





"""
Python module generated from Java source file org.bukkit.event.entity.EntityEnterBlockEvent

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.entity import Entity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityEnterBlockEvent(EntityEvent, Cancellable):
    """
    Called when an Entity enters a block and is stored in that block.
    
    This event is called for bees entering a bee hive.
    
    It is not called when a silverfish "enters" a stone block. For that listen to
    the EntityChangeBlockEvent.
    """

    def __init__(self, entity: "Entity", block: "Block"):
        ...


    def getBlock(self) -> "Block":
        """
        Get the block the entity will enter.

        Returns
        - the block
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.vehicle.VehicleEvent

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Vehicle
from org.bukkit.event import Event
from org.bukkit.event.vehicle import *
from typing import Any, Callable, Iterable, Tuple


class VehicleEvent(Event):
    """
    Represents a vehicle-related event.
    """

    def __init__(self, vehicle: "Vehicle"):
        ...


    def getVehicle(self) -> "Vehicle":
        """
        Get the vehicle.

        Returns
        - the vehicle
        """
        ...



"""
Python module generated from Java source file net.md_5.bungee.chat.ComponentSerializer

Java source file obtained from artifact bungeecord-chat version 1.20-R0.1-20230802.100237-14

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import GsonBuilder
from com.google.gson import JsonDeserializationContext
from com.google.gson import JsonDeserializer
from com.google.gson import JsonElement
from com.google.gson import JsonObject
from com.google.gson import JsonParseException
from com.google.gson import JsonParser
from java.lang.reflect import Type
from net.md_5.bungee.api.chat import BaseComponent
from net.md_5.bungee.api.chat import ItemTag
from net.md_5.bungee.api.chat import KeybindComponent
from net.md_5.bungee.api.chat import ScoreComponent
from net.md_5.bungee.api.chat import SelectorComponent
from net.md_5.bungee.api.chat import TextComponent
from net.md_5.bungee.api.chat import TranslatableComponent
from net.md_5.bungee.api.chat.hover.content import Entity
from net.md_5.bungee.api.chat.hover.content import EntitySerializer
from net.md_5.bungee.api.chat.hover.content import Item
from net.md_5.bungee.api.chat.hover.content import ItemSerializer
from net.md_5.bungee.api.chat.hover.content import Text
from net.md_5.bungee.api.chat.hover.content import TextSerializer
from net.md_5.bungee.chat import *
from typing import Any, Callable, Iterable, Tuple


class ComponentSerializer(JsonDeserializer):

    serializedComponents = ThreadLocal<Set<BaseComponent>>()


    @staticmethod
    def parse(json: str) -> list["BaseComponent"]:
        ...


    @staticmethod
    def toString(object: "Object") -> str:
        ...


    @staticmethod
    def toString(component: "BaseComponent") -> str:
        ...


    @staticmethod
    def toString(*components: Tuple["BaseComponent", ...]) -> str:
        ...


    def deserialize(self, json: "JsonElement", typeOfT: "Type", context: "JsonDeserializationContext") -> "BaseComponent":
        ...



"""
Python module generated from Java source file org.bukkit.entity.Zombie

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Zombie(Monster, Ageable):
    """
    Represents a Zombie.
    """

    def isBaby(self) -> bool:
        """
        Gets whether the zombie is a baby

        Returns
        - Whether the zombie is a baby

        Deprecated
        - see Ageable.isAdult()
        """
        ...


    def setBaby(self, flag: bool) -> None:
        """
        Sets whether the zombie is a baby

        Arguments
        - flag: Whether the zombie is a baby

        Deprecated
        - see Ageable.setBaby() and Ageable.setAdult()
        """
        ...


    def isVillager(self) -> bool:
        """
        Gets whether the zombie is a villager

        Returns
        - Whether the zombie is a villager

        Deprecated
        - check if instanceof ZombieVillager.
        """
        ...


    def setVillager(self, flag: bool) -> None:
        """
        Arguments
        - flag: flag

        Deprecated
        - must spawn ZombieVillager.
        """
        ...


    def setVillagerProfession(self, profession: "Villager.Profession") -> None:
        """
        Arguments
        - profession: profession

        See
        - ZombieVillager.getVillagerProfession()
        """
        ...


    def getVillagerProfession(self) -> "Villager.Profession":
        """
        Returns
        - profession

        See
        - ZombieVillager.getVillagerProfession()
        """
        ...


    def isConverting(self) -> bool:
        """
        Get if this entity is in the process of converting to a Drowned as a
        result of being underwater.

        Returns
        - conversion status
        """
        ...


    def getConversionTime(self) -> int:
        """
        Gets the amount of ticks until this entity will be converted to a Drowned
        as a result of being underwater.
        
        When this reaches 0, the entity will be converted.

        Returns
        - conversion time

        Raises
        - IllegalStateException: if .isConverting() is False.
        """
        ...


    def setConversionTime(self, time: int) -> None:
        """
        Sets the amount of ticks until this entity will be converted to a Drowned
        as a result of being underwater.
        
        When this reaches 0, the entity will be converted. A value of less than 0
        will stop the current conversion process without converting the current
        entity.

        Arguments
        - time: new conversion time
        """
        ...


    def canBreakDoors(self) -> bool:
        """
        Gets whether this zombie can break doors

        Returns
        - Whether this zombie can break doors
        """
        ...


    def setCanBreakDoors(self, flag: bool) -> None:
        """
        Sets whether this zombie can break doors
        
        This will be ignored if the entity is a Drowned. Will also stop the action if
        the entity is currently breaking a door.

        Arguments
        - flag: Whether this zombie can break doors
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.inventory.PrepareSmithingEvent

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event import HandlerList
from org.bukkit.event.inventory import *
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory import ItemStack
from org.bukkit.inventory import SmithingInventory
from typing import Any, Callable, Iterable, Tuple


class PrepareSmithingEvent(PrepareInventoryResultEvent):
    """
    Called when an item is put in a slot for upgrade by a Smithing Table.
    """

    def __init__(self, inventory: "InventoryView", result: "ItemStack"):
        ...


    def getInventory(self) -> "SmithingInventory":
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Dispenser

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Directional
from org.bukkit.block.data import Powerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Dispenser(Directional):
    """
    Similar to Powerable, 'triggered' indicates whether or not the
    dispenser is currently activated.
    """

    def isTriggered(self) -> bool:
        """
        Gets the value of the 'triggered' property.

        Returns
        - the 'triggered' value
        """
        ...


    def setTriggered(self, triggered: bool) -> None:
        """
        Sets the value of the 'triggered' property.

        Arguments
        - triggered: the new 'triggered' value
        """
        ...
